Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 88332 Série: 513 Data de Emissão: 13/11/2018 19:02:29
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4318 1175 3153 3301 2115 6551 3000 0883 3210 4857 9179
Protocolo de Autorização: 143181369407004
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
1908912 | BATATA DOCE | 1,624 | KG | 3,59 | 5,83
1920905 | CENOURA | 0,958 | KG | 2,35 | 2,25
1688983 | TOMATE SALADA | 0,856 | KG | 4,95 | 4,24
2488999 | LARANJA PERA Kg | 2,458 | KG | 2,7 | 6,64
27068977 | MAC.D.BENTA TORTELIN | 1 | UN | 6,25 | 6,25
17978965 | MAC.PETYBON COLOR | 1 | UN | 5,75 | 5,75
46099971 | IOG.DANONE GREGO LGT | 1 | UN | 9,99 | 9,99
41208971 | LEITE FERM.ACTIVIA M | 1 | UN | 9,99 | 9,99
28429975 | ATUM SOLIDO NATURAL | 6 | UN | 6,45 | 38,70
53104889 | RF.MIX C.GRANO CONG | 1 | UN | 7,49 | 7,49
61003900 | GRAO BICO GRANO | 1 | UN | 9,29 | 9,29
48942820 | PEITO PERU SEARA FAT | 2 | UN | 7,95 | 15,90
59114921 | QJO MUSS.FAT.FRIMES | 1 | UN | 13,69 | 13,69
52390900 | CREME FERRERO AVELA | 1 | UN | 26,9 | 26,90
25606910 | MANT.ELEGE TABLETE | 1 | UN | 5,75 | 5,75
14340908 | REQ.ELEGE | 1 | UN | 3,99 | 3,99
60613914 | IOG.DANONE GREGO | 2 | UN | 1,85 | 3,70
54636962 | BISC.CLUB SOCIAL | 1 | UN | 4,85 | 4,85
36874148 | KIWI | 1 | UN | 5,5 | 5,50
5810337 | ALFACE CRESPA HID. | 1 | UN | 2,29 | 2,29
28954968 | BISC.ISABELA TORTINH | 1 | UN | 1,69 | 1,69
28955927 | BISC.ISABELA TORTINH | 1 | UN | 1,69 | 1,69
51583990 | SAC INST.BIO 60X70 | 3 | UN | 0,2 | 0,60
49494133 | PAO INTEGRAL NUTRELL | 2 | UN | 9,58 | 19,16
54320948 | FAR.LACTEA NESTLE | 1 | UN | 14,9 | 14,90
49570912 | AGUA M.DA PEDRA | 8 | UN | 4,39 | 35,12
1075102 | MELANCIA GD | 1 | UN | 16,5 | 16,50
14201952 | LEITE L.VIDA MOLICO | 2 | UN | 3,35 | 6,70
46136903 | AZEITE O.NOVA OLIVA | 1 | UN | 20,9 | 20,90
7082979 | AZEITE GALLO E.V.VDO | 1 | UN | 22,2 | 22,20
43099977 | TORRADA BAUDUCCO | 2 | UN | 2,35 | 4,70
48467818 | SORVETE NESTLE | 1 | UN | 13,48 | 13,48
56772924 | KIT UAU | 1 | UN | 11,65 | 11,65
Valor total R$ | 347,54
Valor descontos R$ | 10,74
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:53